# Contributing to Kryonite Labs projects
We love your input! We want to make contributing to this project as easy and transparent as possible, whether it's:

- Reporting a bug
- Discussing the current state of the code
- Submitting a fix
- Proposing new features
- Becoming a maintainer

Reading and following these guidelines will help us make the contribution process easy and effective for everyone involved. It also communicates that you agree to respect the time of the developers managing and developing these open source projects. In return, we will reciprocate that respect by addressing your issue, assessing changes, and helping you finalize your pull requests.

## Quicklinks

* [Code of Conduct](#code-of-conduct)
* [Getting Started](#getting-started)
    * [Issues](#issues)
    * [Pull Requests](#pull-requests)
* [License](#license)    
* [Getting Help](#getting-help)
* [References](#references)

## Code of Conduct

We take our open source community seriously and hold ourselves and other contributors to high standards of communication. By participating and contributing to this project, you agree to uphold our Code of Conduct. You can find our Code of Conduct in the root directory of every repository. 

## Getting Started

Contributions are made to this repo via Issues, Pull Requests (PRs) and in Github Discussions. A few general guidelines that all of them:

- To report security vulnerabilities, please directly contact use via Discord @lusu007#9305 or @Kev#9168.
- Search for existing Issues and PRs before creating your own.
- We work hard to makes sure issues are handled in a timely manner but, depending on the impact, it could take a while to investigate the root cause. A friendly ping in the comment thread to the submitter or a contributor can help draw attention if your issue is blocking.

### Issues

Issues should be used to report problems with the library, request a new feature, or to discuss potential changes before a PR is created. When you create a new Issue and template is shown please try to provide all information your were asked for.

If you find an Issue that addresses the problem you're having, please add your own reproduction information to the existing issue rather than creating a new one. Adding a [reaction](https://github.blog/2016-03-10-add-reactions-to-pull-requests-issues-and-comments/) can also help be indicating to our maintainers that a particular problem is affecting more than just the reporter.

### Pull Requests

PRs to our libraries are always welcome and can be a quick way to get your fix or improvement slated for the next release. In general, PRs should:

- Only fix/add the functionality in question **OR** address wide-spread whitespace/style issues, not both.
- Add unit or integration tests for fixed or changed functionality (if a test suite already exists).
- Address a single concern in the least number of changed lines as possible.
- Include documentation in the repo if necessary.
- Be accompanied by a complete Pull Request template (if loaded automatically).

For changes that address core functionality or would require breaking changes (e.g. a major release), it's best to open an Issue to discuss your proposal first. This is not required but can save time creating and reviewing changes.

In general, the process is as follows:

1. Fork the repo and create your branch from `main`.
2. Clone the project to your machine.
3. Create a branch locally with a succinct but descriptive name.
4. Commit your changes to the branch.
5. If you've added code that should be tested, add tests.
6. If you've changed APIs, update the documentation.
7. Ensure that all tests pass.
8. Create that pull request!

## License

By contributing, you agree that your contributions will be licensed under its GPL-3.0 License.

## Getting Help

Just post your question in Github Discussions in the correct category with a descriptive title.

## References
This document was adapted from an older version of the open-source contribution guidelines for [Facebook's Draft](https://github.com/facebook/draft-js/blob/master/CONTRIBUTING.md) and [Auth0's open-source-template](https://github.com/auth0/open-source-template/blob/master/CONTRIBUTING.md).